# Checkpoints for Interpolation Models

## RIFE
Checkpoint from December 2020 downloaded following link on the RIFE repository.

It seems the checkpoints linked from the repository have been updated. They don't
work with the vendored model. To make them work probably the vendored code needs
to be upgraded too.

The RIFE repository also contains downloads for the RIFE HD model v3. To make it
work one will probably need to vendor additional code. This can be done in the future.

## CAIN
Checkpoint from December 2020 downloaded following link on the CAIN repository.

At the moment the repository still links to the same checkpoint.
